package com.scansolutions.mrzsdktester

import android.graphics.Bitmap
import android.os.Bundle
import android.os.Handler
import android.os.Looper
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import android.view.View
import com.scansolutions.mrzscannerlib.MRZResultModel
import com.scansolutions.mrzscannerlib.MRZScanner
import com.scansolutions.mrzscannerlib.MRZScannerListener
import com.scansolutions.mrzscannerlib.ScannerType


class MainActivity : AppCompatActivity(), MRZScannerListener {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
    }

    fun startScanner(view: View) {
        ScannerActivity.startScanning(this@MainActivity, ScannerType.SCANNER_TYPE_MRZ)
    }

    fun scanFromGallery(view: View) {
        MRZScanner.scanFromGallery(this@MainActivity, this)
    }

    override fun scanImageFailed() {
        showAlertDialog(R.string.scan_image_failed)
    }

    override fun permissionsWereDenied() {
        showAlertDialog(R.string.permissions_were_denied)
    }

    override fun successfulScanWithDocumentImage(image: Bitmap?) {
    }

    override fun successfulIdFrontImageScan(fullImage: Bitmap?, portrait: Bitmap?) {
    }

    override fun successfulScanWithResult(resultModel: MRZResultModel?) {
        AlertDialog.Builder(this)
                .setMessage(resultModel?.toReadableString())
                .setCancelable(false)
                .setNegativeButton(R.string.close, null)
                .show()
    }

    fun showAlertDialog(message: Int) {
        AlertDialog.Builder(this)
                .setTitle(R.string.error)
                .setMessage(message)
                .setCancelable(false)
                .setNegativeButton(R.string.close, null)
                .show()
    }

    fun scanIdBack(view: View) {
        ScannerActivity.startScanning(this@MainActivity, ScannerType.SCANNER_TYPE_DOC_IMAGE_ID)
    }

    fun scanIdFront(view: View) {
        ScannerActivity.startScanning(this@MainActivity, ScannerType.SCANNER_TYPE_DOC_IMAGE_ID_FRONT)
    }

    fun scanIdSession(view: View) {
        ScannerActivity.startScanning(this@MainActivity, ScannerType.SCANNER_TYPE_ID_SESSION)
    }

    fun hiddenPreviewScannerClick(view: View) {
        ScannerActivity.startScanning(this@MainActivity, ScannerType.SCANNER_TYPE_MRZ, true)
    }

}
