package com.scansolutions.mrzsdktester

import android.content.Context
import android.content.Intent
import android.graphics.Bitmap
import android.os.Bundle
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import android.util.Log
import android.view.Window
import android.view.WindowManager
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.Toast
import android.widget.Toast.LENGTH_LONG
import com.scansolutions.mrzscannerlib.*

class ScannerActivity : AppCompatActivity(), MRZScannerListener {

    lateinit var mrzScanner: MRZScanner

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        window.setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN)
        setContentView(R.layout.activity_scanner)

        val type = intent.getSerializableExtra(TYPE_EXTRA) as ScannerType
        val hidePreview = intent.getBooleanExtra(HIDE_PREVIEW_EXTRA, false)

        MRZScanner.setMaxThreads(2)                    // Set the max CPU threads that the scanner can use
        MRZScanner.registerWithLicenseKey(this,
                "C500C89F1E88DC48B05981B3CB55CEB2D1439B21A4E304A1F7D03D44343C38A61CAFDB25B4C77091C3DA9A9CF7EE8BF96B8E06F0026E517F2E1B91F33B2DC275",
                MRZLicenceResultListener { result, errorMessage ->
                    if (errorMessage != null) {
                        Log.i(TAG, "Result code: " + result.toString() + ". " + errorMessage)
                    } else {
                        Log.i(TAG, "Result code: " + result.toString() + ". Registration successful.")
                    }
                });

        mrzScanner = supportFragmentManager.findFragmentById(R.id.scannerFragment) as MRZScanner
        // Options: [SCANNER_TYPE_MRZ, SCANNER_TYPE_DOC_IMAGE_ID, SCANNER_TYPE_DOC_IMAGE_PASSPORT, SCANNER_TYPE_SWISS_DRIVING_LICENCE, SCANNER_TYPE_DOC_IMAGE_ID_FRONT, SCANNER_TYPE_ID_SESSION]
        mrzScanner.setScannerType(type)
        mrzScanner.setShowFlashButton(false)
        mrzScanner.enableScanFromGallery(true)
        MRZScanner.setExtractFullPassportImageEnabled(true)
        MRZScanner.setExtractPortraitEnabled(true)
        MRZScanner.setExtractSignatureEnabled(true)
        MRZScanner.setEnableUpsideDownScanning(true)

        // Hide preview
        if (hidePreview) {
            mrzScanner.hidePreview();
        }

//        MRZScanner.setPassportActive(false)
//        MRZScanner.setIDActive(false)

//        MRZScanner.setIgnoreInvalidCheckDigitsEnabled(false)
//        MRZScanner.setEnableVibrationOnSuccess(false)
//        mrzScanner.setCustomImageOverlay(R.drawable.overlay)
//        mrzScanner.toggleFlash(true);
//        MRZScanner.setUseFrontCamera(true)

    }

    override fun successfulScanWithDocumentImage(image: Bitmap?) {
        successfulScanWithImages(image)
    }

    private fun successfulScanWithImages(vararg images: Bitmap?) {
        val llContainer = LinearLayout(this@ScannerActivity)
        llContainer.orientation = LinearLayout.VERTICAL
        addImagesToContainer(llContainer, *images)

        AlertDialog.Builder(this)
            .setMessage("Captured image")
            .setPositiveButton(R.string.scan_again) { _, _ ->
                mrzScanner.resumeScanning()
            }
            .setNegativeButton(R.string.close) { _, _ ->
                this@ScannerActivity.finish()
            }
            .setView(llContainer)
            .setCancelable(false)
            .show()
    }

    override fun successfulIdFrontImageScan(fullImage: Bitmap?, portrait: Bitmap?) {
        successfulScanWithImages(fullImage, portrait)
    }

    override fun successfulScanWithResult(resultModel: MRZResultModel) {
        val llContainer = LinearLayout(this@ScannerActivity)
        llContainer.orientation = LinearLayout.VERTICAL
        addImagesToContainer(llContainer, resultModel.idBack, resultModel.idFront)

        AlertDialog.Builder(this@ScannerActivity)
            .setMessage(resultModel.toReadableString())
            .setCancelable(false)
            .setPositiveButton(R.string.resume) { _, _ ->
                mrzScanner.resumeScanning()
            }.setNegativeButton(R.string.close) { _, _ ->
                this@ScannerActivity.finish()
            }.setView(llContainer)
            .show()
    }

    fun addImagesToContainer(container: LinearLayout, vararg images: Bitmap?) {
        for (image in images) {
            if (image != null) {
                val imageView = ImageView(this)
                imageView.setImageBitmap(image)
                container.addView(imageView)
            }
        }
    }

    override fun scanImageFailed() {
        showAlertDialog(R.string.scan_image_failed)
    }

    override fun permissionsWereDenied() {
        showAlertDialog(R.string.permissions_were_denied)
    }

    fun showAlertDialog(message: Int) {
        AlertDialog.Builder(this@ScannerActivity)
            .setTitle(R.string.error)
            .setMessage(message)
            .setCancelable(false)
            .setNegativeButton(R.string.close, null)
            .show()
    }

    companion object {
        private const val TYPE_EXTRA = "TYPE_EXTRA"
        private const val HIDE_PREVIEW_EXTRA = "HIDE_PREVIEW_EXTRA"
        private const val TAG = "ScannerActivity"

        fun startScanning(context: Context, type: ScannerType, hidePreview: Boolean = false) {
            val intent = Intent(context, ScannerActivity::class.java)
            intent.putExtra(TYPE_EXTRA, type)
            intent.putExtra(HIDE_PREVIEW_EXTRA, hidePreview)
            context.startActivity(intent)
        }
    }

}
